@@ -3,7 +3,7 @@ package core
 import (
 	"fmt"
 
-	metav1 "github.com/armosec/kubescape/core/meta/datastructures/v1"
+	metav1 "github.com/armosec/kubescape/v2/core/meta/datastructures/v1"
 )
 
 func (ks *Kubescape) SetCachedConfig(setConfig *metav1.SetConfig) error {
